@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import os
+
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import matplotlib.text as mtext
@@ -356,9 +358,9 @@ def exp_label(
 
 
 def savelabels(
-    fname: str,
+    fname: str = "",
     ax: plt.Axes | None = None,
-    labels: list[str] | dict[str, str] | None = None,
+    labels: list | None = None,
     **kwargs,
 ):
     """
@@ -378,7 +380,7 @@ def savelabels(
 
         Or the combination of labels and filenames can be set manually
 
-        >>> hep.savelabels('test', labels={"FOO": "foo.pdf", "BAR": "bar"})
+        >>> hep.savelabels('test', labels=[("FOO", "foo.pdf"), ("BAR", "bar")])
 
         Which will produce:
         - "FOO" -> "foo.pdf"
@@ -393,38 +395,38 @@ def savelabels(
         Primary filename to be passed to ``plt.savefig``.
     ax : matplotlib.axes.Axes, optional
             Axes object (if None, last one is fetched)
-    labels : dict or list, optional
+    labels : list of tuples, optional
         Mapping of label versions to be produced along with desired savename
         modifications. By default:
-        {
-            "": "",
-            "Preliminary": "pas",
-            "Supplementary": "supp",
-            "Work in Progress": "wip"
-        }
+        [
+            ("", ""),
+            ("Preliminary", "pas"),
+            ("Supplementary", "supp"),
+            ("Work in Progress", "wip"),
+        ]
         If supplied strings contain suffixes such as ".png" the names will be assumed
-        to be absolute and will not incorporate ``fname``.
+        to be absolute and will ignore ``fname``.
         If current label contains "Simulation" this will be perserved.
     """
     if labels is None:
-        labels = {
-            "": "",
-            "Preliminary": "pas",
-            "Supplementary": "supp",
-            "Work in Progress": "wip",
-        }
-    if isinstance(labels, list):
-        labels = {label: label.replace(" ", "_").lower() for label in labels}
+        labels = [
+            ("", ""),
+            ("Preliminary", "pas"),
+            ("Supplementary", "supp"),
+            ("Work in Progress", "wip"),
+        ]
+    if isinstance(labels, list) and isinstance(labels[0], str):
+        labels = [(label, label.replace(" ", "_").lower()) for label in labels]
     if ax is None:
         ax = plt.gca()
 
-    label = [ch for ch in ax.get_children() if isinstance(ch, ExpSuffix)][0]
-    _sim = "Simulation" if "Simulation" in label.get_text() else ""
+    label_base = [ch for ch in ax.get_children() if isinstance(ch, ExpSuffix)][0]
+    _sim = "Simulation" if "Simulation" in label_base.get_text() else ""
 
-    for label_text, suffix in labels.items():
-        label.set_text(" ".join([_sim, label_text]).lstrip())
+    for label_text, suffix in labels:
+        label_base.set_text(" ".join([_sim, label_text]).lstrip())
 
-        if "." in suffix:
+        if "." in suffix:  # absolute paths
             save_name = suffix
         else:
             if len(suffix) > 0:
@@ -434,4 +436,42 @@ def savelabels(
             else:
                 save_name = f"{fname}{suffix}"
 
+        path_dir = os.path.join(save_name.split("/")[:-1])
+        if not os.path.exists(path_dir):
+            os.mkdir(path_dir)
+
         ax.figure.savefig(save_name, **kwargs)
+
+
+def save_variations(fig, name, text_list=None, exp=None):
+    """Lite ``savelabels``
+
+    Parameters
+    ----------
+    fig : figure
+    name : str
+        Savename to pass to `plt.savefig()`
+    text_list : list, optional
+        Variations of ExpSuffix text object to cycle
+        through
+    exp : str, optional
+        Change experiment name label
+    """
+    if text_list is None:
+        text_list = ["Preliminary", ""]
+
+    from mplhep.label import ExpSuffix, ExpText
+
+    for text in text_list:
+        for ax in fig.get_axes():
+            exp_labels = [t for t in ax.get_children() if isinstance(t, ExpText)]
+            suffixes = [t for t in ax.get_children() if isinstance(t, ExpSuffix)]
+            for exp_label, suffix_text in zip(exp_labels, suffixes):
+                if exp is not None:
+                    exp_label.set_text(exp)
+                suffix_text.set_text(text)
+        name_ext = "" if text == "" else "_" + text.lower()
+        if exp is not None:
+            name_ext = exp.lower() + name_ext
+        save_name = name.split(".")[0] + name_ext + "." + name.split(".")[1]
+        fig.savefig(save_name)
