@@ -88,6 +88,7 @@ def histplot(
     histtype="step",
     xerr=False,
     label=None,
+    sort=None,
     edges=True,
     binticks=False,
     ax=None,
@@ -95,6 +96,7 @@ def histplot(
 ):
     """
     Create a 1D histogram plot from `np.histogram`-like inputs.
+
     Parameters
     ----------
         H : object
@@ -113,19 +115,24 @@ def histplot(
             - shape(N) array of for one sided errors or list thereof
             - shape(Nx2) array of for two sided errors or list thereof
         w2 : iterable, optional
-            Sum of the histogram weights squared for poissonian interval error calculation
+            Sum of the histogram weights squared for poissonian interval error
+            calculation
         w2method: callable, optional
             Function calculating CLs with signature ``low, high = fcn(w, w2)``. Here
             ``low`` and ``high`` are given in absolute terms, not relative to w.
             Default is ``None``. If w2 has integer values (likely to be data) poisson
-            interval is calculated, otherwise the resulting error is symmetric ``sqrt(w2)``.
+            interval is calculated, otherwise the resulting error is symmetric
+            ``sqrt(w2)``.
         stack : bool, optional
-            Whether to stack or overlay non-axis dimension (if it exists
+            Whether to stack or overlay non-axis dimension (if it exists). N.B. in
+            contrast to ROOT, stacking is performed in a single call aka
+            ``histplot([h1, h2, ...], stack=True)`` as opposed to multiple calls.
         density : bool, optional
-            If true, convert sum weights to probability density (i.e. integrates to 1 over domain of axis)
-            (Note: this option conflicts with ``binwnorm``)de
+            If true, convert sum weights to probability density (i.e. integrates to 1
+            over domain of axis) (Note: this option conflicts with ``binwnorm``)
         binwnorm : float, optional
-            If true, convert sum weights to bin-width-normalized, with unit equal to supplied value (usually you want to specify 1.)
+            If true, convert sum weights to bin-width-normalized, with unit equal to
+                supplied value (usually you want to specify 1.)
         histtype: {'step', 'fill', 'errorbar'}, optional, default: "step"
             Type of histogram to plot:
 
@@ -136,6 +143,8 @@ def histplot(
             Size of xerr if ``histtype == 'errorbar'``. If ``True``, bin-width will be used.
         label : str or list, optional
             Label for legend entry.
+        sort: {'label'/'l', 'yield'/'y'}, optional
+            Append '_r' for reverse.
         edges : bool, default: True, optional
             Specifies whether to draw first and last edges of the histogram
         binticks : bool, default: False, optional
@@ -298,6 +307,24 @@ def histplot(
         _yerr_lo = _yerr[:, 0]
         _yerr_hi = _yerr[:, 1]
 
+    # Sorting
+    if sort is not None:
+        if sort.split("_")[0] in ["l", "label"] and isinstance(_labels, list):
+            order = np.argsort(label)
+        elif sort.split("_")[0] in ["y", "yield"]:
+            _yields = [np.sum(_h) for _h in h]
+            order = np.argsort(_yields)[::-1]
+        else:
+            raise ValueError(f"Sort type: {sort} not understood.")
+        if len(sort.split("_")) == 2 and sort.split("_")[1] == "r":
+            order = order[::-1]
+
+        h = h[order]
+        _yerr_lo = _yerr_lo[order]
+        _yerr_hi = _yerr_hi[order]
+        _chunked_kwargs = [_chunked_kwargs[ix] for ix in order]
+        _labels = [_labels[ix] for ix in order]
+
     ############################
     # Stacking, norming, density
     if density or binwnorm is not None:
@@ -318,6 +345,9 @@ def histplot(
     # Stack
     if stack and len(hists) > 1:
         h = h[::-1]
+        if yerr is not None:
+            _yerr_lo = _yerr_lo[::-1]
+            _yerr_hi = _yerr_hi[::-1]
         _labels = _labels[::-1]
         _chunked_kwargs = _chunked_kwargs[::-1]
 
@@ -907,41 +937,3 @@ def sort_legend(ax, order=None):
     if isinstance(order, OrderedDict):
         ordered_label_list = [order[k] for k in ordered_label_list]
     return ordered_label_values, ordered_label_list
-
-
-#########################
-# Other helpers
-
-
-def save_variations(fig, name, text_list=None, exp=None):
-    """[summary]
-
-    Parameters
-    ----------
-    fig : figure
-    name : str
-        Savename to pass to `plt.savefig()`
-    text_list : list, optional
-        Variations of ExpSuffix text object to cycle
-        through
-    exp : str, optional
-        Change experiment name label
-    """
-    if text_list is None:
-        text_list = ["Preliminary", ""]
-
-    from mplhep.label import ExpSuffix, ExpText
-
-    for text in text_list:
-        for ax in fig.get_axes():
-            exp_labels = [t for t in ax.get_children() if isinstance(t, ExpText)]
-            suffixes = [t for t in ax.get_children() if isinstance(t, ExpSuffix)]
-            for exp_label, suffix_text in zip(exp_labels, suffixes):
-                if exp is not None:
-                    exp_label.set_text(exp)
-                suffix_text.set_text(text)
-        name_ext = "" if text == "" else "_" + text.lower()
-        if exp is not None:
-            name_ext = exp.lower() + name_ext
-        save_name = name.split(".")[0] + name_ext + "." + name.split(".")[1]
-        fig.savefig(save_name)
